float4x4 mWorldViewProj;
float4x4 mWorld;
float3 cameraPos;
float TerrainHeight;
float FogDistance;
struct VS_OUTPUT
{
	float4 Position : POSITION;
	float4 Diffuse : COLOR0;
	float2 TexCoord0 : TEXCOORD0;
};
VS_OUTPUT vertexMain( in float4 vPosition : POSITION,
					  in float3 vNormal : NORMAL,
					  float2 texCoord0 : TEXCOORD0)
{
	VS_OUTPUT Output;
	Output.Position = mul(vPosition, mWorldViewProj);
	float4 position = mul(vPosition, mWorld);
	float dist = sqrt ( pow(position.x - cameraPos.x, 2.0f) +
                            pow(position.y - cameraPos.y, 2.0f) +
                            pow(position.z - cameraPos.z, 2.0f));
	Output.Diffuse = float4(vPosition.y / TerrainHeight, dist / FogDistance, 0.0f, 0.0f);
	Output.TexCoord0 = texCoord0;
	return Output;
}
struct PS_OUTPUT
{
	float4 RGBColor : COLOR0;
};
sampler2D tex[4];
PS_OUTPUT pixelMain( float2 TexCoord0 : TEXCOORD0,
					 float4 Position : POSITION,
					 float4 Diffuse : COLOR0 )
{
	PS_OUTPUT Output;	
	float heightpercent = Diffuse.x;
	float dist = Diffuse.y;
	float4 fog = float4(0.39, 0.39, 0.39, 1.0);
	if(dist >= 1.0f)
	{
		Output.RGBColor = fog;
	}
	else
	{
		float4 grasscolor = tex2D(tex[0], TexCoord0 * 5.0f) * pow((1.0f - heightpercent), 2.0f);	
		float4 rockcolor = tex2D(tex[1], TexCoord0 * 20.0f) * pow((1.0f - abs(0.5f - heightpercent)), 4.0f);
		float4 snowcolor = tex2D(tex[2], TexCoord0 * 5.0f) * pow(heightpercent,4.0f);	
		float4 detailcolor = tex2D(tex[3], TexCoord0 * 20.0f);
		Output.RGBColor = (grasscolor + rockcolor + snowcolor) * detailcolor * 2.0f;
		Output.RGBColor *= (1.0f - dist);
		Output.RGBColor += fog * dist;
	}
	return Output;
}